# logthis.py
import requests

def log_this(header, message, color, webhook, footer=None):
    if footer:
        footer_text = f"{footer}"
    else:
        footer_text = None

    color_code = None
    if color.startswith('#'):
        color_code = int(color[1:], 16)
    elif color.lower() == 'success':
        color_code = int("5cb85c", 16)
    elif color.lower() == 'info':
        color_code = int("5bc0de", 16)
    elif color.lower() == 'warning':
        color_code = int("f0ad4e", 16)
    elif color.lower() == 'danger':
        color_code = int("d9534f", 16)

    data = {
        "embeds": [
            {
                "title": header,
                "description": message,
                "color": color_code,
                "footer": {"text": footer_text}
            }
        ]
    }

    headers = {'Content-Type': 'application/json'}
    result = requests.post(webhook, json=data, headers=headers)
    try:
        result.raise_for_status()
    except requests.exceptions.HTTPError as err:
        print(err)



# tests/test_logthis.py
import unittest
from PyLogDc.logthis import log_this


class TestLogThis(unittest.TestCase):
    def test_log_this(self):
        webhookURL = "https://discord.com/api/webhooks/......."
        try:
            log_this('Test Header', 'Test message', 'info', webhookURL)
        except Exception as e:
            self.fail(f"log_this raised an exception {e}")


if __name__ == '__main__':
    unittest.main()



# setup.py
from setuptools import setup, find_packages

with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

setup(
    name='pylogdc',
    version='0.1.3',
    author='Trnass',
    author_email='admin@trnass.cz',
    description='Python package for logging actions to Discord servers using webhooks.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/Trnass/PyLogDc',
    packages=find_packages(),
    install_requires=[
        'requests',
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
